@@ -81,6 +81,21 @@ then
 
 fi
 
+if ask_section "Generate API difference (using frapuccino)"
+then
+    echo $BLUE"Checking out $PREV_RELEASE"$NOR
+    git checkout $PREV_RELEASE
+    echo $BLUE"Saving API to file $PREV_RELEASE"$NOR
+    frappuccino IPython --save IPython-$PREV_RELEASE.json
+    echo $BLUE"comming back to $BRANCH"$NOR
+    git checkout $BRANCH
+    echo $BLUE"comparing ..."$NOR
+    frappuccino IPython --compare IPython-$PREV_RELEASE.json
+    echo $GREEN"Use the above guideline to write an API changelog ..."$NOR
+    echo $GREEN"Press any keys to continue"$NOR
+    read
+fi
+
 echo "Cleaning repository"
 git clean -xfdi
 
@@ -98,12 +113,6 @@ then
 
 fi
 
-echo
-echo $BLUE"Attempting to build package..."$NOR
-
-tools/build_release
-rm dist/*
-
 if ask_section "Should we commit, tag, push... etc ? "
 then
    echo
@@ -160,14 +169,41 @@ fi
 
 if ask_section "Should we build and release ?"
 then
+    
+    echo $BLUE"going to set SOURCE_DATE_EPOCH"$NOR
+    echo $BLUE'export SOURCE_DATE_EPOCH=$(git show -s --format=%ct HEAD)'$NOR
+    echo $GREEN"Press enter to continue"$NOR
+    read
+
+    export SOURCE_DATE_EPOCH=$(git show -s --format=%ct HEAD)
+
+    echo $BLUE"SOURCE_DATE_EPOCH set to $SOURCE_DATE_EPOCH"$NOR
+    echo $GREEN"Press enter to continue"$NOR
+    read
+
+
 
     echo
     echo $BLUE"Attempting to build package..."$NOR
 
     tools/release
 
-    echo $RED
-    echo '$ shasum -a 256 dist/*'
+
+    echo $RED'$ shasum -a 256 dist/*'
+    shasum -a 256 dist/*
+    echo $NOR
+
+    echo $BLUE"We are going to rebuild, node the hash above, and compare them to the rebuild"$NOR
+    echo $GREEN"Press enter to continue"$NOR
+    read
+
+    echo
+    echo $BLUE"Attempting to build package..."$NOR
+
+    tools/release
+
+    echo $RED"Check the shasum for SOURCE_DATE_EPOCH=$SOURCE_DATE_EPOCH"
+    echo $RED'$ shasum -a 256 dist/*'
     shasum -a 256 dist/*
     echo $NOR
 
